#ifndef _CPUID_H_
#define _CPUID_H_

/* 
   When cpuid is called with a value of 0 in the
   EAX register, it returns a list of values in the
   EDX register. Each bit represents a feature
   (excluding reserved bits). If the bit is set, the
   feature exists. If it's cleared the feature
   isn't supported.
*/
#define CHECKFEATURE_ERROR  0x10000001	/* cpu feature check had a problem, call cpuFeatures */
#define CHECKFEATURE_X87FPU 0x00000001  /* cpu has x87 fpu */
#define CHECKFEATURE_VMODEE 0x00000002  /* cpu has Virtual 8086 mode enhancement */
#define CHECKFEATURE_DEBEXT 0x00000004  /* cpu has debugging extensions */
#define CHECKFEATURE_PGSEXT	0x00000008  /* cpu has page extensions */
#define CHECKFEATURE_TSCOUN	0x00000010  /* cpu has time stamp counter */
#define CHECKFEATURE_XXMSRS	0x00000020  /* cpu has RDMSR/WRMSR inst support */
#define CHECKFEATURE_PHAEXT	0x00000040  /* cpu has physical address extension */
#define CHECKFEATURE_MCHEXT	0x00000080  /* cpu has machine check exception */
#define CHECKFEATURE_CMPXCH	0x00000100  /* cpu has 8 byte cmp and xchg inst support */
#define CHECKFEATURE_APICON	0x00000200  /* cpu has APIC on chip */
#define CHECKFEATURE_SYSXXX	0x00000800  /* cpu has SYSENTER/SYSLEAVE */
#define CHECKFEATURE_MTRREG	0x00001000  /* cpu has memory type range registers */
#define CHECKFEATURE_PTEBIT	0x00002000  /* cpu has global PTE bit */
#define CHECKFEATURE_MCKARC	0x00004000  /* cpu has machine check architexture */
#define CHECKFEATURE_CMOVIN	0x00008000  /* cpu has CMOV inst support */
#define CHECKFEATURE_PGATTT	0x00010000  /* cpu has page attribute table */
#define CHECKFEATURE_PGSEX2	0x00020000  /* cpu has page size extension */
#define CHECKFEATURE_SERNUM	0x00040000  /* cpu has processor serial number */
#define CHECKFEATURE_CFLUSH	0x00080000  /* processor supports CFLUSH inst */
#define CHECKFEATURE_DBSTOR	0x00200000  /* cpu has debug store */
#define CHECKFEATURE_ACPICT	0x00400000  /* ACPI on processor */
#define CHECKFEATURE_MMXCMP	0x00800000  /* cpu has MMX technology */
#define CHECKFEATURE_FXXSTO	0x01000000	/* cpu supports FXSAVE/FXRSTORE inst */
#define CHECKFEATURE_SSEEXT	0x02000000  /* cpu has SSE extensions */
#define CHECKFEATURE_SSE2EX 0x04000000  /* cpu has sse2 extensions */
#define CHECKFEATURE_SSNOOP	0x08000000  /* cpu supports system snoop */
#define CHECKFEATURE_PTHERM	0x10000000  /* cpu has process thermomitor */


#ifdef _cplusplus
extern "C"
{
#endif

/* When called, obtains a list of features the cpu supports */
extern unsigned int __cdecl cpuFeatures	    (void);
/* 
   Pass this one of the above defined features, -1 = error and
   if it returns the same value passed the feature exists if it
   returns 0 then the feature is un supported
*/
extern unsigned int __cdecl cpuCheckFeature (unsigned int feature); 
/*
	Returns a pointer to a string that the processor sends to
	the EBX, EDX, and ECX registers. e.g. GenuineIntel or
	AuthenticAMD. 
*/
extern char* __cdecl		cpuID			(void);

#ifdef _cplusplus
}
#endif

#endif